==> haskell-data-serializer-0.3.5-215-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-ALNqwQe4Ku52Aw8yYMZfWl
key:                  data-serializer-0.3.5-ALNqwQe4Ku52Aw8yYMZfWl
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  16810ded57978a03c997506074e05eb5
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-ALNqwQe4Ku52Aw8yYMZfWl
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    data-endian-0.1.1-8VgB7oHHi3LDrYxCrUtoWs
    parsers-0.12.11-JRRvaRVdh9J4z6OxNpJgDX
    split-0.2.5-3yHGsS1jHoyLHpkVbnU0Aa

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.5-216-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-K3Or5ig0qJaB5bwKlTX1N2
key:                  data-serializer-0.3.5-K3Or5ig0qJaB5bwKlTX1N2
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  2f4acdaa14aac3a5414c481e72b4d85e
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-K3Or5ig0qJaB5bwKlTX1N2
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    data-endian-0.1.1-8VgB7oHHi3LDrYxCrUtoWs
    parsers-0.12.11-3Olv36rVcwNKjCPKUxIaL4
    split-0.2.5-3yHGsS1jHoyLHpkVbnU0Aa

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
